=======
DONATE!
=======

.. _BitCoins: https://en.wikipedia.org/wiki/Bitcoin
.. _4A86FE43: http://pgp.rediris.es:11371/pks/lookup?search=0x4A86FE43&op=vindex&fingerprint=on&exact=on

Work on this project is currently driven by my own interests, needs and
spare time. If you appreciate this software or if you want to sponsor a
currently not translated API feature, please consider donation to the
project.

PyBSDDB/BSDDB3 needs your help.

You can donate using BitCoins_. The destination address is
16avqyUK4vDqBdpUy365PPW44zNqVHLZSC.

.. image:: bitcoin.png
   :align: center
   :alt: 16avqyUK4vDqBdpUy365PPW44zNqVHLZSC.

Since donations thru BitCoin are not revocable, please be sure your are
transfering to the right account (this document could have been modified
for a third party). You can verify it in two diffent ways:

1. Reading this document in the project original website:
   `http://www.jcea.es/programacion/pybsddb_doc/donate.html
   <http://www.jcea.es/programacion/pybsddb_doc/donate.html>`__. Make
   sure you are seeing the right webpage.

2. Verifying the PGP digital signature of the following document:

   .. code-block:: none

     -----BEGIN PGP SIGNED MESSAGE-----
     Hash: SHA256

     The BitCoin address for donating to PyBSDDB/BSDDB3 project
     is "16avqyUK4vDqBdpUy365PPW44zNqVHLZSC".

     -----BEGIN PGP SIGNATURE-----
     Version: GnuPG v1

     iQEcBAEBCAAGBQJT0AKrAAoJEGjgN61Khv5DK1kH/3JctpZUr+h8iFCfpRCaHsX8
     +6dmncm3ebAWt9kCRqZZ74Eq8h9918C4UwxLLPrskAIqQw3g2IyTdaPOHomM23XH
     Ru1ok5fhCjNMCw4+dnnO/AXxEY6cIf2PjsQlkUznCe0zz1ndZQ33XbdI/1ItUEhy
     nZVWblnCCAQnO69Nhf6vPxfRDol1oDTh0bginhflmS01P2r8m9Mzx9h7Rrx7oKwG
     meNIVIzwdA+Tbex0GvQGorPSwEuid/mVYuDp9jSLp8XgeXBQfeqPWv+PO2tkijYE
     Zs1A1YuFA3S8uDnZhe9P7u4w7PGlCNIrDvTyippXiYB9fnSHu6mPmCw3wv+SWkM=
     =9xWm
     -----END PGP SIGNATURE-----

   Doing something like :kbd:`gpg --verify` and pasting this block, your
   should get something like:

   .. code-block:: none

      gpg: Signature made Wed 23 Jul 2014 08:44:59 PM CEST using RSA key ID 4A86FE43
      gpg: Good signature from "Jesús Cea Avión <jcea@jcea.es>"

   My PGP key ID is "4A86FE43_". My key fingerprint is::

    pub   4096R/1567BC0F 2014-01-13
          Key fingerprint = 8627 62C4 6EC3 567C B58C  7FB1 A510 404E 1567 BC0F
	  uid                  Jesús Cea Avión <jcea@jcea.es>
	  sub   2048R/4A86FE43 2014-01-13
	  sub   2048R/05488493 2014-01-13

